==> adam-cli-spark3_2.12-1.0-sources.jar: org/bdgenomics/adam/cli/About.java <==
/**
 * Licensed to Big Data Genomics (BDG) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The BDG licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.bdgenomics.adam.cli;

/**
 * About.
 */
public final class About {
    private static final String ARTIFACT_ID = "adam-cli-spark3_2.12";
    private static final String BUILD_TIMESTAMP = "2022-05-23";
    private static final String COMMIT = "dd94f1d561ed95c28bfe7295f0bcfbf72b06f519";
    private static final String SCALA_VERSION = "2.12.15";
    private static final String SPARK_VERSION = "3.2.1";
    private static final String VERSION = "1.0";

    /**
     * Return the artifact id.
     *
     * @return the artifact id
     */
    public String artifactId() {
        return ARTIFACT_ID;
    }

    /**
     * Return the build timestamp.
     *
     * @return the build timestamp
     */
    public String buildTimestamp() {
        return BUILD_TIMESTAMP;
    }

    /**
     * Return the last commit.
     *
     * @return the last commit
     */
    public String commit() {
        return COMMIT;
    }

    /**
     * Return the Scala compile scope dependency version.
     *
     * @return the Scala compile scope dependency version
     */
    public String scalaVersion() {
        return SCALA_VERSION;
    }

    /**
     * Return the Apache Spark compile scope dependency version.
     *
     * @return the Apache Spark compile scope dependency version
     */
    public String sparkVersion() {
        return SPARK_VERSION;
    }

    /**
     * Return the ADAM version.
     *
     * @return the ADAM version
     */
    public String version() {
        return VERSION;
    }

    /**
     * Return true if the ADAM version is a snapshot.
     *
     * @return true if the ADAM version is a snapshot
     */
    public boolean isSnapshot() {
        return VERSION.contains("SNAPSHOT");
    }
}

==> adam-cli-spark3_2.12-1.0.1-sources.jar: org/bdgenomics/adam/cli/About.java <==
/**
 * Licensed to Big Data Genomics (BDG) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The BDG licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.bdgenomics.adam.cli;

/**
 * About.
 */
public final class About {
    private static final String ARTIFACT_ID = "adam-cli-spark3_2.12";
    private static final String BUILD_TIMESTAMP = "2024-01-04";
    private static final String COMMIT = "1a5686b900232f39dcd72f59bc4f8d7c064f591f";
    private static final String SCALA_VERSION = "2.12.18";
    private static final String SPARK_VERSION = "3.3.4";
    private static final String VERSION = "1.0.1";

    /**
     * Return the artifact id.
     *
     * @return the artifact id
     */
    public String artifactId() {
        return ARTIFACT_ID;
    }

    /**
     * Return the build timestamp.
     *
     * @return the build timestamp
     */
    public String buildTimestamp() {
        return BUILD_TIMESTAMP;
    }

    /**
     * Return the last commit.
     *
     * @return the last commit
     */
    public String commit() {
        return COMMIT;
    }

    /**
     * Return the Scala compile scope dependency version.
     *
     * @return the Scala compile scope dependency version
     */
    public String scalaVersion() {
        return SCALA_VERSION;
    }

    /**
     * Return the Apache Spark compile scope dependency version.
     *
     * @return the Apache Spark compile scope dependency version
     */
    public String sparkVersion() {
        return SPARK_VERSION;
    }

    /**
     * Return the ADAM version.
     *
     * @return the ADAM version
     */
    public String version() {
        return VERSION;
    }

    /**
     * Return true if the ADAM version is a snapshot.
     *
     * @return true if the ADAM version is a snapshot
     */
    public boolean isSnapshot() {
        return VERSION.contains("SNAPSHOT");
    }
}
